.. currentmodule:: pvlib

Transposition models
--------------------

.. autosummary::
   :toctree: ../generated/

   irradiance.get_total_irradiance
   irradiance.get_sky_diffuse
   irradiance.isotropic
   irradiance.perez
   irradiance.haydavies
   irradiance.klucher
   irradiance.reindl
   irradiance.king
